@@ -17,7 +17,6 @@ checkfail()
 #############
 
 RELEASE=0
-GDB_FILE=""
 while [ $# -gt 0 ]; do
     case $1 in
         help|--help)
@@ -35,10 +34,6 @@ while [ $# -gt 0 ]; do
         release|--release)
             RELEASE=1
             ;;
-        --gdb)
-            GDB_FILE="$2"
-            shift
-            ;;
     esac
     shift
 done
@@ -304,11 +299,6 @@ SRC_DIR=$PWD
 NDK_TOOLCHAIN_PATH=`echo ${ANDROID_NDK}/toolchains/${PATH_HOST}-${GCCVER}/prebuilt/\`uname|tr A-Z a-z\`-*/bin`
 CROSS_COMPILE=${NDK_TOOLCHAIN_PATH}/${TARGET_TUPLE}-
 
-if [ ! -z "$GDB_FILE" ];then
-    ${CROSS_COMPILE}gdb "$GDB_FILE"
-    exit 0
-fi
-
 export PATH=${NDK_TOOLCHAIN_PATH}:${PATH}
 
 ###############
@@ -663,6 +653,11 @@ fi
 
 echo "Building NDK"
 
+HAVE_LIBCOMPAT=
+if [ "${ANDROID_API}" = "android-9" ] && [ "${ANDROID_ABI}" = "armeabi-v7a" -o "${ANDROID_ABI}" = "armeabi" ] ; then
+    HAVE_LIBCOMPAT=1
+fi
+
 $ANDROID_NDK/ndk-build -C libvlc \
     VLC_SRC_DIR="$VLC_SRC_DIR" \
     ANDROID_SYS_HEADERS="$ANDROID_SYS_HEADERS" \
@@ -682,11 +677,12 @@ $ANDROID_NDK/ndk-build -C libvlc \
     HAVE_64=${HAVE_64} \
     NDK_PROJECT_PATH=jni \
     NDK_TOOLCHAIN_VERSION=${GCCVER} \
-    NDK_DEBUG=${NDK_DEBUG}
+    NDK_DEBUG=${NDK_DEBUG} \
+    HAVE_LIBCOMPAT=${HAVE_LIBCOMPAT}
 
 checkfail "ndk-build failed"
 
-if [ "${ANDROID_API}" = "android-9" ] && [ "${ANDROID_ABI}" = "armeabi-v7a" -o "${ANDROID_ABI}" = "armeabi" ] ; then
+if [ "${HAVE_LIBCOMPAT}" = "1" ];then
     $ANDROID_NDK/ndk-build -C libvlc \
         APP_BUILD_SCRIPT=libcompat/Android.mk \
         APP_PLATFORM=${ANDROID_API} \
