@@ -22,7 +22,6 @@ package org.videolan.libvlc.util;
 
 import android.net.Uri;
 import android.os.Build;
-import android.util.Log;
 
 import java.io.File;
 
@@ -43,6 +42,10 @@ public class AndroidUtil {
         return android.os.Build.VERSION.SDK_INT >= Build.VERSION_CODES.HONEYCOMB_MR1;
     }
 
+    public static boolean isHoneycombMr2OrLater() {
+        return android.os.Build.VERSION.SDK_INT >= Build.VERSION_CODES.HONEYCOMB_MR2;
+    }
+
     public static boolean isICSOrLater() {
         return Build.VERSION.SDK_INT >= Build.VERSION_CODES.ICE_CREAM_SANDWICH;
     }
