@@ -353,7 +353,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     private OnAudioFocusChangeListener createOnAudioFocusChangeListener() {
         return new OnAudioFocusChangeListener() {
             private boolean mLossTransient = false;
-            private boolean mLossTransientCanDuck = false;
+            private int mLossTransientVolume = -1;
             private boolean wasPlaying = false;
 
             @Override
@@ -380,16 +380,16 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                         Log.i(TAG, "AUDIOFOCUS_LOSS_TRANSIENT_CAN_DUCK");
                         // Lower the volume
                         if (mMediaPlayer.isPlaying()) {
+                            mLossTransientVolume = mMediaPlayer.getVolume();
                             mMediaPlayer.setVolume(36);
-                            mLossTransientCanDuck = true;
                         }
                         break;
                     case AudioManager.AUDIOFOCUS_GAIN:
-                        Log.i(TAG, "AUDIOFOCUS_GAIN: " + mLossTransientCanDuck + ", " + mLossTransient);
+                        Log.i(TAG, "AUDIOFOCUS_GAIN: " + mLossTransientVolume + ", " + mLossTransient);
                         // Resume playback
-                        if (mLossTransientCanDuck) {
-                            mMediaPlayer.setVolume(100);
-                            mLossTransientCanDuck = false;
+                        if (mLossTransientVolume != -1) {
+                            mMediaPlayer.setVolume(mLossTransientVolume);
+                            mLossTransientVolume = -1;
                         } else if (mLossTransient) {
                             if (wasPlaying)
                                 mMediaPlayer.play();
@@ -568,7 +568,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
             if (update) {
                 for (Callback callback : mCallbacks)
                     callback.onMediaEvent(event);
-                if (mParsed)
+                if (mParsed && mMediaSession != null)
                     showNotification();
             }
         }
@@ -595,6 +595,9 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         public void onEvent(MediaPlayer.Event event) {
             switch (event.type) {
                 case MediaPlayer.Event.Playing:
+                    if(mSavedTime != 0l)
+                        seek(mSavedTime);
+                    mSavedTime = 0l;
 
                     Log.i(TAG, "MediaPlayer.Event.Playing");
                     executeUpdate();
@@ -1083,6 +1086,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     }
 
     private final class MediaSessionCallback extends MediaSessionCompat.Callback {
+
         @Override
         public void onPlay() {
             play();
@@ -1109,7 +1113,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
 
         @Override
         public void onSeekTo(long pos) {
-            setTime(pos);
+            seek(pos);
         }
 
         @Override
@@ -1220,9 +1224,9 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
 
     @MainThread
     public void previous() {
-        int size = mMediaList.size();
         if (hasPrevious() && mCurrentIndex > 0 &&
                 (!mMediaPlayer.isSeekable() || mMediaPlayer.getTime() < 2000l)) {
+            int size = mMediaList.size();
             mCurrentIndex = mPrevIndex;
             if (mPrevious.size() > 0)
                 mPrevious.pop();
@@ -1231,11 +1235,10 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                 stop();
                 return;
             }
+            playIndex(mCurrentIndex, 0);
+            saveCurrentMedia();
         } else
             setPosition(0f);
-
-        playIndex(mCurrentIndex, 0);
-        saveCurrentMedia();
     }
 
     @MainThread
@@ -1341,7 +1344,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         // load playlist
         loadLocations(mediaPathList, position);
         if (time > 0)
-            setTime(time);
+            seek(time);
         if(!audio) {
             boolean paused = mSettings.getBoolean(PreferencesActivity.VIDEO_PAUSED, !isPlaying());
             float rate = mSettings.getFloat(PreferencesActivity.VIDEO_SPEED, getRate());
@@ -1724,7 +1727,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
             public void run() {
                 final ArrayList<Media.Slave> list = MediaDatabase.getInstance().getSlaves(mw.getLocation());
                 for (Media.Slave slave : list)
-                    mMediaPlayer.addSlave(slave.type, Uri.parse(slave.uri));
+                    mMediaPlayer.addSlave(slave.type, Uri.parse(slave.uri), false);
             }
         });
 
@@ -1739,9 +1742,6 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
             changeAudioFocus(true);
             mMediaPlayer.setEventListener(mMediaPlayerListener);
             mMediaPlayer.play();
-            if(mSavedTime != 0l)
-                mMediaPlayer.setTime(mSavedTime);
-            mSavedTime = 0l;
 
             determinePrevAndNextIndices();
             if (mSettings.getBoolean(PreferencesFragment.PLAYBACK_HISTORY, true))
@@ -1993,6 +1993,24 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         return mMediaPlayer.setVolume(volume);
     }
 
+    @MainThread
+    public void seek(long position) {
+        seek(position, getLength());
+    }
+
+    @MainThread
+    public void seek(long position, double length) {
+        if (length > 0.0D)
+            setPosition((float) (position/length));
+        else
+            setTime(position);
+    }
+
+    @MainThread
+    public void saveTimeToSeek(long time) {
+        mSavedTime = time;
+    }
+
     @MainThread
     public void setPosition(float pos) {
         if (mSeekable)
@@ -2024,14 +2042,24 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         return mMediaPlayer.getVideoTracksCount();
     }
 
+    @MainThread
+    public boolean addSubtitleTrack(String path, boolean select) {
+        return mMediaPlayer.addSlave(Media.Slave.Type.Subtitle, path, select);
+    }
+
+    @MainThread
+    public boolean addSubtitleTrack(Uri uri,boolean select) {
+        return mMediaPlayer.addSlave(Media.Slave.Type.Subtitle, uri, select);
+    }
+
     @MainThread
     public boolean addSubtitleTrack(String path) {
-        return mMediaPlayer.addSlave(Media.Slave.Type.Subtitle, path);
+        return addSubtitleTrack(path, false);
     }
 
     @MainThread
     public boolean addSubtitleTrack(Uri uri) {
-        return mMediaPlayer.addSlave(Media.Slave.Type.Subtitle, uri);
+        return addSubtitleTrack(uri, false);
     }
 
     @MainThread
