@@ -34,7 +34,6 @@ import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.browser.MediaBrowserFragment;
-import org.videolan.vlc.gui.view.DividerItemDecoration;
 import org.videolan.vlc.gui.view.SwipeRefreshLayout;
 import org.videolan.vlc.interfaces.IHistory;
 import org.videolan.vlc.interfaces.IRefreshable;
@@ -59,15 +58,6 @@ public class HistoryFragment extends MediaBrowserFragment implements IRefreshabl
         mHistoryAdapter = new HistoryAdapter();
     }
 
-    private void focusHelper(boolean idIsEmpty) {
-        MainActivity main = (MainActivity)getActivity();
-        if (main == null)
-            return;
-        main.setMenuFocusDown(idIsEmpty, android.R.id.list);
-        main.setSearchAsFocusDown(idIsEmpty, getView(),
-                android.R.id.list);
-    }
-
     @Override
     @TargetApi(Build.VERSION_CODES.HONEYCOMB)
     public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState){
@@ -76,7 +66,6 @@ public class HistoryFragment extends MediaBrowserFragment implements IRefreshabl
         mRecyclerView = (RecyclerView)v.findViewById(android.R.id.list);
         mEmptyView = v.findViewById(android.R.id.empty);
         mLayoutManager = new LinearLayoutManager(getActivity());
-        mRecyclerView.addItemDecoration(new DividerItemDecoration(VLCApplication.getAppContext(), DividerItemDecoration.VERTICAL_LIST));
         mRecyclerView.setLayoutManager(mLayoutManager);
         mRecyclerView.setAdapter(mHistoryAdapter);
         mRecyclerView.setNextFocusUpId(R.id.ml_menu_search);
@@ -84,7 +73,6 @@ public class HistoryFragment extends MediaBrowserFragment implements IRefreshabl
         mRecyclerView.setNextFocusRightId(android.R.id.list);
         if (AndroidUtil.isHoneycombOrLater())
             mRecyclerView.setNextFocusForwardId(android.R.id.list);
-        focusHelper(mHistoryAdapter.getItemCount() == 0);
         mRecyclerView.requestFocus();
         registerForContextMenu(mRecyclerView);
 
@@ -151,14 +139,11 @@ public class HistoryFragment extends MediaBrowserFragment implements IRefreshabl
         public void handleMessage(Message msg) {
             switch (msg.what){
                 case UPDATE_LIST:
-                    focusHelper(mHistoryAdapter.isEmpty());
                     mHistoryAdapter.setList((ArrayList<MediaWrapper>) msg.obj);
                     updateEmptyView();
                     if( mHistoryAdapter != null ) {
                         mHistoryAdapter.notifyDataSetChanged();
-                        focusHelper(mHistoryAdapter.getItemCount() == 0);
-                    } else
-                        focusHelper(true);
+                    }
                     mSwipeRefreshLayout.setRefreshing(false);
                     getActivity().supportInvalidateOptionsMenu();
             }
