@@ -37,7 +37,6 @@ import android.view.ViewGroup;
 import android.widget.BaseAdapter;
 import android.widget.ImageView;
 import android.widget.SectionIndexer;
-import android.widget.TextView;
 
 import org.videolan.vlc.BR;
 import org.videolan.vlc.R;
@@ -45,7 +44,6 @@ import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.helpers.AsyncImageLoader;
 import org.videolan.vlc.gui.helpers.AudioUtil;
 import org.videolan.vlc.gui.helpers.MediaComparators;
-import org.videolan.vlc.gui.helpers.UiTools;
 import org.videolan.vlc.interfaces.IAudioClickHandler;
 import org.videolan.vlc.media.MediaUtils;
 import org.videolan.vlc.media.MediaWrapper;
@@ -98,7 +96,7 @@ public class AudioBrowserListAdapter extends BaseAdapter implements SectionIndex
         final public boolean mIsSeparator;
 
         public ListItem(String title, String subTitle, MediaWrapper media, boolean isSeparator) {
-            mMediaList = new ArrayList<MediaWrapper>();
+            mMediaList = new ArrayList<>();
             if (media != null)
                 mMediaList.add(media);
             mTitle = title;
@@ -108,10 +106,10 @@ public class AudioBrowserListAdapter extends BaseAdapter implements SectionIndex
     }
 
     public AudioBrowserListAdapter(Activity context, int itemType) {
-        mMediaItemMap = new ArrayMap<String, ListItem>();
-        mSeparatorItemMap = new ArrayMap<String, ListItem>();
-        mItems = new ArrayList<ListItem>();
-        mSections = new SparseArray<String>();
+        mMediaItemMap = new ArrayMap<>();
+        mSeparatorItemMap = new ArrayMap<>();
+        mItems = new ArrayList<>();
+        mSections = new SparseArray<>();
         mContext = context;
         if (itemType != ITEM_WITHOUT_COVER && itemType != ITEM_WITH_COVER)
             throw new IllegalArgumentException();
@@ -260,8 +258,7 @@ public class AudioBrowserListAdapter extends BaseAdapter implements SectionIndex
                     firstSeparator = false;
                     sections.add(firstCharInString);
                 }
-            }
-            else if (firstSeparator) {
+            } else if (firstSeparator) {
                 ListItem item = new ListItem("#", null, null, true);
                 mItems.add(i, item);
                 mSections.put(i, "#");
@@ -354,35 +351,26 @@ public class AudioBrowserListAdapter extends BaseAdapter implements SectionIndex
             holder = new ViewHolder();
             holder.binding = DataBindingUtil.inflate(inflater, R.layout.audio_browser_item, parent, false);
             v = holder.binding.getRoot();
-            UiTools.setAlignModeByPref(mAlignMode, (TextView) v.findViewById(R.id.title));
             holder.viewType = VIEW_MEDIA;
             v.setTag(holder);
         }
 
         ListItem item = getItem(position);
+        holder.binding.setVariable(BR.alignMode, mAlignMode);
         holder.binding.setVariable(BR.item, item);
         holder.binding.setVariable(BR.position, position);
 
-        final ArrayList<MediaWrapper> mediaList = mItems.get(position).mMediaList;
-        boolean asyncLoad = true;
-
         if (mItemType == ITEM_WITH_COVER) {
-            Bitmap bitmap = AudioUtil.getCoverFromMemCache(mContext, mediaList, 64);
-            if (bitmap != null) {
-                asyncLoad = false;
-                holder.binding.setVariable(BR.cover, new BitmapDrawable(VLCApplication.getAppResources(), bitmap));
-            } else {
-                holder.binding.setVariable(BR.cover, AudioUtil.DEFAULT_COVER);
-            }
+            //Tagging the binding to the ImageView will trigger async image loading with:
+            // org.videolan.vlc.gui.helpers.AsyncImageLoader.loadPicture(ImageView , AudioBrowserListAdapter.ListItem)
+            holder.binding.getRoot().findViewById(R.id.media_cover).setTag(holder.binding);
         } else
             holder.binding.setVariable(BR.cover, AudioUtil.DEFAULT_COVER);
 
-        holder.binding.setVariable(BR.footer, !isMediaItemAboveASeparator(position));
+        holder.binding.setVariable(BR.hasFooter, !isMediaItemAboveASeparator(position));
         holder.binding.setVariable(BR.clickable, mContextPopupMenuListener != null);
         holder.binding.setVariable(BR.handler, this);
         holder.binding.executePendingBindings();
-        if (asyncLoad)
-            AsyncImageLoader.LoadImage(new AudioCoverFetcher(holder.binding, mContext, mediaList), null);
 
         return v;
     }
@@ -599,28 +587,4 @@ public class AudioBrowserListAdapter extends BaseAdapter implements SectionIndex
         if (mContextPopupMenuListener != null)
             mContextPopupMenuListener.onPopupMenu(v, ((Integer)v.getTag()).intValue());
     }
-
-    private static class AudioCoverFetcher extends AsyncImageLoader.CoverFetcher {
-        final ArrayList<MediaWrapper> list;
-        final Context context;
-
-        AudioCoverFetcher(ViewDataBinding binding, Context context, ArrayList<MediaWrapper> list) {
-            super(binding);
-            this.context = context;
-            this.list = list;
-        }
-
-        @Override
-        public Bitmap getImage() {
-            return AudioUtil.getCover(context, list, 64);
-        }
-
-        @Override
-        public void updateBindImage(Bitmap bitmap, View target) {
-            if (bitmap != null && (bitmap.getWidth() != 1 && bitmap.getHeight() != 1)) {
-                binding.setVariable(BR.scaleType, ImageView.ScaleType.FIT_CENTER);
-                binding.setVariable(BR.cover, new BitmapDrawable(VLCApplication.getAppResources(), bitmap));
-            }
-        }
-    }
 }
