@@ -66,7 +66,6 @@ public class EqualizerFragment extends PlaybackServiceFragment {
         super.onCreateView(inflater, container, savedInstanceState);
         View v = inflater.inflate(R.layout.equalizer, container, false);
         saveViewChildren(v);
-        fillViews();
 
         return v;
     }
@@ -155,6 +154,12 @@ public class EqualizerFragment extends PlaybackServiceFragment {
             VLCOptions.setEqualizer(getActivity(), null, 0);
     }
 
+    @Override
+    public void onResume() {
+        super.onResume();
+        fillViews();
+    }
+
     private final OnItemSelectedListener mPresetListener = new OnItemSelectedListener() {
         @Override
         public void onItemSelected(AdapterView<?> parent, View view, int pos, long id) {
