@@ -51,7 +51,7 @@ public class FilePickerAdapter extends BaseBrowserAdapter {
         vh.binding.setMedia(media);
         vh.binding.setHasContextMenu(false);
         vh.binding.setType(TYPE_MEDIA);
-        vh.binding.setProtocole(null);
+        vh.binding.setProtocol(null);
         vh.binding.executePendingBindings();
 
         vh.binding.dviIcon.setBackgroundResource(getIconResId(media));
