@@ -39,6 +39,7 @@ import android.support.v7.widget.GridLayoutManager;
 import android.support.v7.widget.RecyclerView;
 import android.text.TextUtils;
 import android.text.format.DateFormat;
+import android.view.Gravity;
 import android.view.KeyEvent;
 import android.view.LayoutInflater;
 import android.view.View;
@@ -55,12 +56,12 @@ import org.videolan.vlc.gui.SecondaryActivity;
 import org.videolan.vlc.gui.helpers.UiTools;
 import org.videolan.vlc.gui.preferences.PreferencesUi;
 import org.videolan.vlc.gui.video.VideoPlayerActivity;
+import org.videolan.vlc.gui.view.AutoFitRecyclerView;
 import org.videolan.vlc.interfaces.IPlaybackSettingsController;
 import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.util.AndroidDevices;
 import org.videolan.vlc.util.Permissions;
 import org.videolan.vlc.util.Strings;
-import org.videolan.vlc.gui.view.AutoFitRecyclerView;
 
 import java.util.ArrayList;
 import java.util.Calendar;
@@ -116,6 +117,8 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
 
     private IPlaybackSettingsController mPlaybackController;
 
+    private Toast mToast;
+
     public AdvOptionsDialog() {}
 
     @Override
@@ -169,6 +172,9 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
         mAdapter = new AdvOptionsAdapter();
         mRecyclerView.setAdapter(mAdapter);
 
+        mToast = Toast.makeText(VLCApplication.getAppContext(), "", Toast.LENGTH_SHORT);
+        mToast.setGravity(Gravity.TOP,0,100);
+
         //Get default color
         int[] attrs = new int[] { android.R.attr.textColorSecondary };
         TypedArray a = getActivity().getTheme().obtainStyledAttributes(R.style.Theme_VLC, attrs);
@@ -453,10 +459,7 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
                 }
                 break;
             case ID_PLAYBACK_SPEED:
-                if (mMode == MODE_AUDIO)
                     showFragment(ID_PLAYBACK_SPEED);
-                else
-                    showValueControls(ACTION_PLAYBACK_SPEED);
                 break;
             case ID_CHAPTER_TITLE:
                 showFragment(ID_CHAPTER_TITLE);
@@ -503,6 +506,8 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
         if (v instanceof TextView)
             ((TextView) v).setTextColor(v.hasFocus() ?
                     FOCUSED_TEXT_COLOR : mTextColor);
+        mToast.setText(mAdapter.getSelectedAdvOptionHelp());
+        mToast.show();
     }
 
 
@@ -665,6 +670,10 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
             notifyItemInserted(mList.size()-1);
         }
 
+        public String getSelectedAdvOptionHelp () {
+            return mList.get(getSelection()).text;
+        }
+
         public void setSelection(int position) {
             if (mSelection == position || position < 0 || position >= mList.size())
                 return;
@@ -690,7 +699,9 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
 
             @Override
             public boolean onLongClick(View view) {
-                Toast.makeText(VLCApplication.getAppContext(), mList.get(getAdapterPosition()).text, Toast.LENGTH_SHORT).show();
+                Toast toast = Toast.makeText(VLCApplication.getAppContext(), mList.get(getAdapterPosition()).text, Toast.LENGTH_SHORT);
+                toast.setGravity(Gravity.TOP,0,0);
+                toast.show();
                 return true;
             }
         }
