@@ -171,14 +171,14 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
     @Override
     public void onResume() {
         super.onResume();
-        if ((getActivity() instanceof MainActivity))
+        if (getActivity() instanceof MainActivity)
             mMainActivity = (MainActivity) getActivity();
         mMediaLibrary.setBrowser(this);
         mMediaLibrary.addUpdateHandler(mHandler);
-        final boolean refresh = mVideoAdapter.isEmpty();
+        final boolean refresh = mVideoAdapter.isEmpty() && !mMediaLibrary.isWorking();
         // We don't animate while medialib is scanning. Because gridview is being populated.
         // That would lead to graphical glitches
-        final boolean animate = mGroup == null && refresh && !mMediaLibrary.isWorking();
+        final boolean animate = mGroup == null && refresh;
         if (refresh)
             updateList();
         else {
@@ -190,10 +190,6 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
         updateViewMode();
         if (animate)
             mAnimator.animate();
-
-        /* Start the thumbnailer */
-        if (mThumbnailer != null)
-            mThumbnailer.start(this);
     }
 
     @Override
@@ -311,7 +307,7 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
                     }, new Runnable() {
                         @Override
                         public void run() {
-                            mVideoAdapter.add(position, media);
+                            mVideoAdapter.add(media);
                         }
                     });
                 return true;
@@ -365,7 +361,6 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
         media.release();
         menu.findItem(R.id.video_list_info).setVisible(hasInfo);
         menu.findItem(R.id.video_list_delete).setVisible(canWrite);
-        menu.findItem(R.id.video_download_subtitles).setVisible(canWrite);
         if (!AndroidUtil.isHoneycombOrLater()) {
             menu.findItem(R.id.video_list_play_all).setVisible(false);
             menu.findItem(R.id.video_list_append).setVisible(false);
@@ -384,7 +379,10 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
     private Handler mHandler = new VideoListHandler(this);
 
     public void updateItem(MediaWrapper item) {
+        if (item.getType() != MediaWrapper.TYPE_VIDEO)
+            return;
         mVideoAdapter.update(item);
+        mViewNomedia.setVisibility(View.GONE);
     }
 
     public void updateList() {
@@ -392,39 +390,42 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
             mSwipeRefreshLayout.setRefreshing(true);
         final List<MediaWrapper> itemList = mMediaLibrary.getVideoItems();
 
-        if (mThumbnailer != null)
-            mThumbnailer.clearJobs();
-        else
-            Log.w(TAG, "Can't generate thumbnails, the thumbnailer is missing");
-
         if (itemList.size() > 0) {
             VLCApplication.runBackground(new Runnable() {
                 @Override
                 public void run() {
                     final ArrayList<MediaWrapper> displayList = new ArrayList<>();
-
+                    final ArrayList<MediaWrapper> jobsList = new ArrayList<>();
                     if (mGroup != null || itemList.size() <= 10) {
                         for (MediaWrapper item : itemList) {
-                            if (mGroup == null || item.getTitle().startsWith(mGroup)) {
+                            if (mGroup == null || item.getTitle().startsWith(mGroup))
                                 displayList.add(item);
-                                if (mThumbnailer != null)
-                                    mThumbnailer.addJob(item);
-                            }
+                                jobsList.add(item);
                         }
-                    }
-                    else {
+                    } else {
                         List<MediaGroup> groups = MediaGroup.group(itemList);
                         for (MediaGroup item : groups) {
                             displayList.add(item.getMedia());
-                            if (mThumbnailer != null)
-                                mThumbnailer.addJob(item.getMedia());
+                            for (MediaWrapper media : item.getAll())
+                                jobsList.add(media);
                         }
                     }
 
-                    mVideoAdapter.addAll(displayList);
-                    mVideoAdapter.sort();
-                    if (mReadyToDisplay)
-                        display();
+                    mHandler.post(new Runnable() {
+                        @Override
+                        public void run() {
+                            mVideoAdapter.clear();
+                            mVideoAdapter.addAll(displayList);
+                            if (mReadyToDisplay)
+                                display();
+                        }
+                    });
+                    if (mThumbnailer != null && !jobsList.isEmpty()) {
+                        mThumbnailer.clearJobs();
+                        mThumbnailer.start(VideoGridFragment.this);
+                        for (MediaWrapper item : jobsList)
+                            mThumbnailer.addJob(item);
+                    }
                 }
             });
         }
@@ -466,7 +467,8 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
     }
 
     public void setItemToUpdate(MediaWrapper item) {
-        mHandler.sendMessage(mHandler.obtainMessage(VideoListHandler.UPDATE_ITEM, item));
+        if (mVideoAdapter.contains(item))
+            mHandler.sendMessage(mHandler.obtainMessage(MediaLibrary.UPDATE_ITEM, item));
     }
 
     public void setGroup(String prefix) {
