@@ -26,6 +26,7 @@ import android.databinding.ViewDataBinding;
 import android.support.annotation.MainThread;
 import android.support.annotation.Nullable;
 import android.support.v4.util.ArrayMap;
+import android.support.v7.util.SortedList;
 import android.support.v7.widget.RecyclerView;
 import android.view.LayoutInflater;
 import android.view.View;
@@ -45,12 +46,9 @@ import org.videolan.vlc.util.Strings;
 
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Collections;
-import java.util.Comparator;
 import java.util.Locale;
 
-public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.ViewHolder>
-        implements Comparator<MediaWrapper> {
+public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.ViewHolder> {
 
     public final static String TAG = "VLC/VideoListAdapter";
 
@@ -61,11 +59,10 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
     public final static int TYPE_GRID = 1;
 
     public final static int SORT_BY_DATE = 2;
-    private int mSortDirection = 1;
-    private int mSortBy = SORT_BY_TITLE;
     private boolean mListMode = false;
     private VideoGridFragment mFragment;
-    private volatile ArrayList<MediaWrapper> mVideos = new ArrayList<>();
+    private VideoComparator mVideoComparator = new VideoComparator();
+    private volatile SortedList<MediaWrapper> mVideos = new SortedList<>(MediaWrapper.class, mVideoComparator);
     private ImageView mThumbnail;
 
     public VideoListAdapter(VideoGridFragment fragment) {
@@ -91,11 +88,14 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
 
     @Override
     public void onBindViewHolder(ViewHolder holder, int position) {
-        MediaWrapper media = mVideos.get(position);
+        MediaWrapper media = getItem(position);
+        if (media == null)
+            return;
         holder.binding.setVariable(BR.scaleType, ImageView.ScaleType.FIT_CENTER);
         fillView(holder, media);
 
         holder.binding.setVariable(BR.media, media);
+        holder.binding.executePendingBindings();
     }
 
     @MainThread
@@ -114,75 +114,16 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
             notifyDataSetChanged();
     }
 
-    public int sortDirection(int sortby) {
-        if (sortby == mSortBy)
-            return  mSortDirection;
-        else
-            return -1;
-    }
-
-    public void sortBy(int sortby) {
-        switch (sortby) {
-            case SORT_BY_TITLE:
-                if (mSortBy == SORT_BY_TITLE)
-                    mSortDirection *= -1;
-                else {
-                    mSortBy = SORT_BY_TITLE;
-                    mSortDirection = 1;
-                }
-                break;
-            case SORT_BY_LENGTH:
-                if (mSortBy == SORT_BY_LENGTH)
-                    mSortDirection *= -1;
-                else {
-                    mSortBy = SORT_BY_LENGTH;
-                    mSortDirection *= 1;
-                }
-                break;
-            case SORT_BY_DATE:
-                if (mSortBy == SORT_BY_DATE)
-                    mSortDirection *= -1;
-                else {
-                    mSortBy = SORT_BY_DATE;
-                    mSortDirection *= 1;
-                }
-                break;
-            default:
-                mSortBy = SORT_BY_TITLE;
-                mSortDirection = 1;
-                break;
-        }
-        sort();
-    }
-
     public void sort() {
         if (!isEmpty())
             try {
-                Collections.sort(mVideos, this);
+                resetSorting();
             } catch (ArrayIndexOutOfBoundsException e) {} //Exception happening on Android 2.x
     }
 
     public boolean isEmpty()
     {
-        return mVideos.isEmpty();
-    }
-
-    @Override
-    public int compare(MediaWrapper item1, MediaWrapper item2) {
-        int compare = 0;
-        switch (mSortBy) {
-            case SORT_BY_TITLE:
-                compare = item1.getTitle().toUpperCase(Locale.ENGLISH).compareTo(
-                        item2.getTitle().toUpperCase(Locale.ENGLISH));
-                break;
-            case SORT_BY_LENGTH:
-                compare = ((Long) item1.getLength()).compareTo(item2.getLength());
-                break;
-            case SORT_BY_DATE:
-                compare = ((Long) item1.getLastModified()).compareTo(item2.getLastModified());
-                break;
-        }
-        return mSortDirection * compare;
+        return mVideos.size() == 0;
     }
 
     @Nullable
@@ -194,54 +135,44 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
     }
 
     public void add(MediaWrapper item) {
-        mVideos.add(item);
-    }
-
-    public void add(int position, MediaWrapper item) {
-        mVideos.add(position, item);
-        notifyItemInserted(position);
-    }
-
-    @MainThread
-    public void remove(MediaWrapper item) {
-        remove(getItemPosition(item));
+        notifyItemInserted(mVideos.add(item));
     }
 
     @MainThread
     public void remove(int position) {
         if (position == -1)
             return;
-        mVideos.remove(position);
+        mVideos.removeItemAt(position);
         notifyItemRemoved(position);
     }
 
-    private int getItemPosition(MediaWrapper mw) {
-        if (mw == null || mVideos.isEmpty())
-            return -1;
-        for (int i = 0 ; i < mVideos.size(); ++i){
-            if (mw.equals(mVideos.get(i)))
-                return i;
-        }
-        return -1;
+    public void addAll(Collection<MediaWrapper> items) {
+        mVideos.addAll(items);
     }
 
-    public void addAll(Collection<MediaWrapper> items) {
-        mVideos.clear();
-        mVideos.addAll(items);
-
+    public boolean contains(MediaWrapper mw) {
+        return mVideos.indexOf(mw) != -1;
     }
 
     public ArrayList<MediaWrapper> getAll() {
-        return mVideos;
+        int size = mVideos.size();
+        ArrayList<MediaWrapper> list = new ArrayList<>(size);
+        for (int i = 0; i < size; ++i)
+            list.add(mVideos.get(i));
+        return list;
     }
 
     @MainThread
     public void update(MediaWrapper item) {
         int position = mVideos.indexOf(item);
         if (position != -1) {
-            mVideos.set(position, item);
+            if (!(mVideos.get(position) instanceof MediaGroup))
+                mVideos.updateItemAt(position, item);
+            notifyItemChanged(position);
+        } else {
+            position = mVideos.add(item);
+            notifyItemRangeChanged(position, mVideos.size()-position);
         }
-        notifyItemChanged(position);
     }
 
     public void clear() {
@@ -319,7 +250,9 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
         }
 
         public void onClick(View v){
-            MediaWrapper media = mVideos.get(getAdapterPosition());
+            MediaWrapper media = getItem(getAdapterPosition());
+            if (media == null)
+                return;
             if (media instanceof MediaGroup) {
                 MainActivity activity = (MainActivity) mFragment.getActivity();
                 activity.showSecondaryFragment(SecondaryActivity.VIDEO_GROUP_LIST, media.getTitle());
@@ -351,4 +284,109 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
                 itemView.setBackgroundColor(UiTools.ITEM_FOCUS_OFF);
         }
     }
+    public int sortDirection(int sortDirection) {
+        return mVideoComparator.sortDirection(sortDirection);
+    }
+
+    public void sortBy(int sortby) {
+        mVideoComparator.sortBy(sortby);
+    }
+
+    private void resetSorting() {
+        ArrayList<MediaWrapper> list = getAll();
+        mVideos.clear();
+        mVideos.addAll(list);
+        notifyItemRangeChanged(0, mVideos.size());
+    }
+
+    public class VideoComparator extends SortedList.Callback<MediaWrapper> {
+
+        private int mSortDirection = 1;
+        private int mSortBy = SORT_BY_TITLE;
+
+        public int sortDirection(int sortby) {
+            if (sortby == mSortBy)
+                return  mSortDirection;
+            else
+                return -1;
+        }
+
+        public void sortBy(int sortby) {
+            switch (sortby) {
+                case SORT_BY_TITLE:
+                    if (mSortBy == SORT_BY_TITLE)
+                        mSortDirection *= -1;
+                    else {
+                        mSortBy = SORT_BY_TITLE;
+                        mSortDirection = 1;
+                    }
+                    break;
+                case SORT_BY_LENGTH:
+                    if (mSortBy == SORT_BY_LENGTH)
+                        mSortDirection *= -1;
+                    else {
+                        mSortBy = SORT_BY_LENGTH;
+                        mSortDirection *= 1;
+                    }
+                    break;
+                case SORT_BY_DATE:
+                    if (mSortBy == SORT_BY_DATE)
+                        mSortDirection *= -1;
+                    else {
+                        mSortBy = SORT_BY_DATE;
+                        mSortDirection *= 1;
+                    }
+                    break;
+                default:
+                    mSortBy = SORT_BY_TITLE;
+                    mSortDirection = 1;
+                    break;
+            }
+            resetSorting();
+        }
+
+        @Override
+        public int compare(MediaWrapper item1, MediaWrapper item2) {
+            int compare = 0;
+            switch (mSortBy) {
+                case SORT_BY_TITLE:
+                    compare = item1.getTitle().toUpperCase(Locale.ENGLISH).compareTo(
+                            item2.getTitle().toUpperCase(Locale.ENGLISH));
+                    break;
+                case SORT_BY_LENGTH:
+                    compare = ((Long) item1.getLength()).compareTo(item2.getLength());
+                    break;
+                case SORT_BY_DATE:
+                    compare = ((Long) item1.getLastModified()).compareTo(item2.getLastModified());
+                    break;
+            }
+            return mSortDirection * compare;
+        }
+
+        @Override
+        public void onInserted(int position, int count) {}
+
+        @Override
+        public void onRemoved(int position, int count) {}
+
+        @Override
+        public void onMoved(int fromPosition, int toPosition) {}
+
+        @Override
+        public void onChanged(int position, int count) {}
+
+        @Override
+        public boolean areContentsTheSame(MediaWrapper oldItem, MediaWrapper newItem) {
+            return areItemsTheSame(oldItem, newItem);
+        }
+
+        @Override
+        public boolean areItemsTheSame(MediaWrapper item1, MediaWrapper item2) {
+            if (item1 == item2)
+                return true;
+            if (item1 == null ^ item2 == null)
+                return false;
+            return item1.equals(item2);
+        }
+    }
 }
