@@ -35,7 +35,6 @@ import android.os.Message;
 import android.support.v7.app.AlertDialog;
 import android.support.v7.app.AppCompatActivity;
 import android.support.v7.preference.PreferenceManager;
-import android.text.TextUtils;
 import android.util.Log;
 import android.view.View;
 import android.view.WindowManager;
@@ -46,6 +45,8 @@ import org.videolan.vlc.BuildConfig;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.helpers.UiTools;
+import org.videolan.vlc.gui.video.VideoPlayerActivity;
+import org.videolan.vlc.media.MediaDatabase;
 import org.videolan.vlc.media.MediaWrapper;
 
 import java.io.File;
@@ -86,22 +87,29 @@ public class SubtitlesDownloader {
     private volatile boolean stop = false;
 
     private AlertDialog mSumUpDialog;
+    private Callback mCallback;
+
+    public interface Callback {
+        void onRequestEnded(boolean success);
+    }
 
     public void setActivity(Activity activity) {
         mContext = activity;
     }
 
-    public void downloadSubs(final List<MediaWrapper> mediaList) {
+    public void downloadSubs(final List<MediaWrapper> mediaList, Callback cb) {
         stop = false;
+        mCallback = cb;
         Set<String> languages =  Collections.singleton(Locale.getDefault().getISO3Language().toLowerCase());
         if (AndroidUtil.isHoneycombOrLater()) {
-            SharedPreferences pref = PreferenceManager.getDefaultSharedPreferences(mContext);
+            SharedPreferences pref = PreferenceManager.getDefaultSharedPreferences(VLCApplication.getAppContext());
             languages =  pref.getStringSet("languages_download_list", languages);
         }
         final ArrayList<String> finalLanguages = new ArrayList<>(languages);
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
+                FileUtils.SUBTITLES_DIRECTORY.mkdirs();
                 if (logIn()){
                     getSubtitles(mediaList, finalLanguages);
                 }
@@ -158,55 +166,57 @@ public class SubtitlesDownloader {
         for (String language : languages)
             language = getCompliantLanguageID(language);
         final boolean single = mediaList.size() == 1;
-        ArrayList<MediaWrapper> notFoundFiles = new ArrayList<>();
-        HashMap<String, String> index = new HashMap<>();
-        HashMap<String, ArrayList<String>> success = new HashMap<>();
-        HashMap<String, ArrayList<String>> fails = new HashMap<>();
+        final ArrayList<MediaWrapper> notFoundFiles = new ArrayList<>();
+        final HashMap<String, String> index = new HashMap<>();
+        final HashMap<String, ArrayList<String>> success = new HashMap<>();
+        final HashMap<String, ArrayList<String>> fails = new HashMap<>();
         ArrayList<HashMap<String, String>> videoSearchList = prepareRequestList(mediaList, languages, index, true);
         Object[] subtitleMaps;
-        try {
-            map = (HashMap<String, Object>) mClient.call("SearchSubtitles", mToken, videoSearchList);
-        } catch (Throwable e) { //for various service outages
-            stop = true;
-            showSnackBar(R.string.service_unavailable);
-            return;
-        }
-        if(!stop && map.get("data") instanceof Object[]) {
-            subtitleMaps = ((Object[]) map.get("data"));
-            if (!single)
-                mHandler.obtainMessage(DIALOG_UPDATE_PROGRESS, mediaList.size(), 0).sendToTarget();
-            if (subtitleMaps.length > 0){
-                String srtFormat, movieHash, fileUrl, fileName, subLanguageID, subDownloadLink;
-                for (Object map : subtitleMaps){
-                    if (stop)
-                        break;
-                    srtFormat = ((HashMap<String, String>) map).get("SubFormat");
-                    movieHash = ((HashMap<String, String>) map).get("MovieHash");
-                    subLanguageID = ((HashMap<String, String>) map).get("SubLanguageID");
-                    subDownloadLink = ((HashMap<String, String>) map).get("SubDownloadLink");
-                    fileUrl = index.get(movieHash);
+        if (!videoSearchList.isEmpty()) {
+            try {
+                map = (HashMap<String, Object>) mClient.call("SearchSubtitles", mToken, videoSearchList);
+            } catch (Throwable e) { //for various service outages
+                stop = true;
+                showSnackBar(R.string.service_unavailable);
+                return;
+            }
+            if(!stop && map.get("data") instanceof Object[]) {
+                subtitleMaps = ((Object[]) map.get("data"));
+                if (!single)
+                    mHandler.obtainMessage(DIALOG_UPDATE_PROGRESS, mediaList.size(), 0).sendToTarget();
+                if (subtitleMaps.length > 0){
+                    String srtFormat, movieHash, fileUrl, fileName, subLanguageID, subDownloadLink;
+                    for (Object map : subtitleMaps){
+                        if (stop)
+                            break;
+                        srtFormat = ((HashMap<String, String>) map).get("SubFormat");
+                        movieHash = ((HashMap<String, String>) map).get("MovieHash");
+                        subLanguageID = ((HashMap<String, String>) map).get("SubLanguageID");
+                        subDownloadLink = ((HashMap<String, String>) map).get("SubDownloadLink");
+                        fileUrl = index.get(movieHash);
 
-                    fileName = fileUrl.substring(fileUrl.lastIndexOf('/') + 1);
-                    if (success.containsKey(fileName) && success.get(fileName).contains(subLanguageID)){
-                        continue;
-                    } else {
-                        if (success.containsKey(fileName))
-                            success.get(fileName).add(subLanguageID);
-                        else {
-                            ArrayList<String> newLanguage = new ArrayList<>();
-                            newLanguage.add(subLanguageID);
-                            success.put(fileName, newLanguage);
+                        fileName = fileUrl.substring(fileUrl.lastIndexOf('/') + 1);
+                        if (success.containsKey(fileName) && success.get(fileName).contains(subLanguageID)){
+                            continue;
+                        } else {
+                            if (success.containsKey(fileName))
+                                success.get(fileName).add(subLanguageID);
+                            else {
+                                ArrayList<String> newLanguage = new ArrayList<>();
+                                newLanguage.add(subLanguageID);
+                                success.put(fileName, newLanguage);
+                            }
                         }
+                        downloadSubtitles(subDownloadLink, fileUrl, fileName, srtFormat, subLanguageID);
+                        if (!single)
+                            mHandler.obtainMessage(DIALOG_UPDATE_PROGRESS, mediaList.size(), success.size()).sendToTarget();
                     }
-                    downloadSubtitles(subDownloadLink, fileUrl, fileName, srtFormat, subLanguageID);
-                    if (!single)
-                        mHandler.obtainMessage(DIALOG_UPDATE_PROGRESS, mediaList.size(), success.size()).sendToTarget();
                 }
             }
+            if (videoSearchList != null)
+                videoSearchList.clear();
+            index.clear();
         }
-        if (videoSearchList != null)
-            videoSearchList.clear();
-        index.clear();
 
         //Second pass
         for (MediaWrapper media : mediaList){
@@ -282,6 +292,13 @@ public class SubtitlesDownloader {
                     fails.put(fileName, langs);
             }
         }
+        if (mCallback != null)
+            mHandler.post(new Runnable() {
+                @Override
+                public void run() {
+                    mCallback.onRequestEnded(!success.isEmpty());
+                }
+            });
         if (!stop) {
             if (single){
                 stop = true;
@@ -293,22 +310,14 @@ public class SubtitlesDownloader {
         logOut();
     }
 
-    private void downloadSubtitles(String subUrl, String path, String name, String subFormat, String language){
+    private void downloadSubtitles(String subUrl, String path, String fileName, String subFormat, String language){
         if (mToken == null || path == null)
             return;
 
-        final File parent = new File(path).getParentFile();
-        boolean canWrite = !path.startsWith("smb://") && !path.startsWith("http://") && parent != null && parent.canWrite();
-        String fileUrl;
         StringBuilder sb = new StringBuilder();
-        if (canWrite){
-            fileUrl = path;
-            sb.append(fileUrl.substring(0,fileUrl.lastIndexOf('.')+1)).append(language).append('.').append(subFormat);
-        } else{
-            fileUrl = name;
-            sb.append(VLCApplication.getAppContext().getFilesDir().getPath()).append('/').append(fileUrl).append('.').append(language).append('.').append(subFormat);
-        }
-        String srtURl = sb.toString();
+        String name = fileName.lastIndexOf('.') > 0 ? fileName.substring(0, fileName.lastIndexOf('.')) : fileName;
+        sb.append(FileUtils.SUBTITLES_DIRECTORY.getPath()).append('/').append(name).append('.').append(language).append('.').append(subFormat);
+        String srtUrl = sb.toString();
         FileOutputStream f = null;
         InputStream in = null;
         GZIPInputStream gzIS = null;
@@ -318,7 +327,7 @@ public class SubtitlesDownloader {
             url  = new URL(subUrl);
             urlConnection = (HttpURLConnection) url.openConnection();
             // We get the first matching subtitle
-            f = new FileOutputStream(new File(srtURl));
+            f = new FileOutputStream(new File(srtUrl));
             //Base64 then gunzip uncompression
             gzIS = new GZIPInputStream(urlConnection.getInputStream());
             int length;
@@ -326,7 +335,7 @@ public class SubtitlesDownloader {
             while ((length = gzIS.read(buffer)) != -1) {
                 f.write(buffer, 0, length);
             }
-            // TODO Update the media database
+            MediaDatabase.getInstance().saveSubtitle(srtUrl, fileName);
         } catch (IOException e) {
             if (BuildConfig.DEBUG) Log.e(TAG, "download fail", e);
         } catch (Throwable e) { //for various service outages
@@ -348,7 +357,7 @@ public class SubtitlesDownloader {
             long fileLength = 0;
             Uri mediaUri = media.getUri();
             if (firstPass) {
-                if (TextUtils.equals(mediaUri.getScheme(), "file") && FileUtils.canWrite(mediaUri.toString())) {
+                if (FileUtils.canWrite(mediaUri)) {
                     File videoFile = new File(mediaUri.getPath());
                     hash = FileUtils.computeHash(videoFile);
                     fileLength = videoFile.length();
@@ -416,18 +425,22 @@ public class SubtitlesDownloader {
     private String buildSumup(HashMap<String, ArrayList<String>> success, HashMap<String, ArrayList<String>> fails, boolean single) {
         StringBuilder textToDisplay = new StringBuilder();
         if (single){ // Text for the toast
-            for (Entry<String, ArrayList<String>> entry : success.entrySet()) {
-                textToDisplay.append(VLCApplication.getAppResources().getString(R.string.snack_subloader_sub_found));
-                if (entry.getValue().size() > 1)
-                    textToDisplay.append(" ").append(entry.getValue().toString()).append("\n");
+            if (!success.isEmpty()) {
+                for (Entry<String, ArrayList<String>> entry : success.entrySet()) {
+                    textToDisplay.append(VLCApplication.getAppResources().getString(R.string.snack_subloader_sub_found));
+                    if (entry.getValue().size() > 1)
+                        textToDisplay.append(" ").append(entry.getValue().toString()).append("\n");
+                }
             }
-            for (Entry<String, ArrayList<String>> entry : fails.entrySet()){
-                textToDisplay.append(VLCApplication.getAppResources().getString(R.string.snack_subloader_sub_not_found));
-                if (entry.getValue().size() > 1)
-                    textToDisplay.append(" ").append(entry.getValue().toString()).append("\n");
+            if (!fails.isEmpty()) {
+                for (Entry<String, ArrayList<String>> entry : fails.entrySet()){
+                    textToDisplay.append(VLCApplication.getAppResources().getString(R.string.snack_subloader_sub_not_found));
+                    if (entry.getValue().size() > 1)
+                        textToDisplay.append(" ").append(entry.getValue().toString()).append("\n");
+                }
             }
         } else { // Text for the dialog box
-            if (success.size()>0){
+            if (!success.isEmpty()){
                 textToDisplay.append(VLCApplication.getAppResources().getString(R.string.dialog_subloader_success)).append("\n");
 
                 for (Entry<String, ArrayList<String>> entry : success.entrySet()){
@@ -440,7 +453,7 @@ public class SubtitlesDownloader {
                     textToDisplay.append("\n\n");
             }
 
-            if (fails.size()>0){
+            if (!fails.isEmpty()){
                 textToDisplay.append(VLCApplication.getAppResources().getString(R.string.dialog_subloader_fails)).append("\n");
 
                 for (Entry<String, ArrayList<String>> entry : fails.entrySet()){
@@ -486,7 +499,7 @@ public class SubtitlesDownloader {
     private void showSnackBar(final String text) {
         if (mContext == null)
             return;
-        if (mContext instanceof AppCompatActivity) {
+        if (mContext instanceof AppCompatActivity && !(mContext instanceof VideoPlayerActivity)) {
             mHandler.post(new Runnable() {
                 @Override
                 public void run() {
@@ -511,9 +524,14 @@ public class SubtitlesDownloader {
         public void handleMessage(Message msg) {
             if (mContext == null || mContext.isFinishing())
                 return;
+            if (mContext instanceof VideoPlayerActivity) {
+                if (msg.what == DIALOG_SHOW)
+                    showSnackBar(R.string.downloading_subtitles);
+                return;
+            }
             switch (msg.what) {
                 case DIALOG_SHOW:
-                    mDialog = ProgressDialog.show(mContext, "Subs download", "Connecting...", true);
+                    mDialog = ProgressDialog.show(mContext, mContext.getString(R.string.subtitles_download_title), mContext.getString(R.string.connecting), true);
                     mDialog.setOnCancelListener(new DialogInterface.OnCancelListener() {
                         @Override
                         public void onCancel(DialogInterface dialog) {
